.. _matrices-docs:

========
Matrices
========

.. automodule:: sympy.matrices

Contents:

.. toctree::
   :maxdepth: 2

   matrices.rst
   dense.rst
   sparse.rst
   immutablematrices.rst
   expressions.rst
